# Easy Letters

Easy Letters is a Python package to help job seekers write cover and application letters. It uses retrieval augmented
generation (or RAG) paradigm to generate draft letters based on the user's input. The user can then edit the draft
letter to suit their needs.

## Installation

You can install Easy Letters using pip:

```bash
pip install easy-letters
```